from charms.reactive import hook, when, set_state, remove_state
from charmhelpers import fetch
from charmhelpers.core import hookenv
from charmhelpers.core.host import lsb_release, CompareHostReleases
from charmhelpers.contrib.charmsupport import nrpe
from lib_infra_node import InfranodeHelper


helper = InfranodeHelper()


@when('nrpe.render', 'nrpe-external-master.available')
def update_nrpe_config():
    # python-dbus is used by check_upstart_job, libnagios-plugin-perl is used by the pacemaker checks.
    # The package was renamed in Bionic.
    _release = lsb_release()['DISTRIB_CODENAME'].lower()
    if CompareHostReleases(_release) <= 'xenial':
        fetch.apt_install(['python-dbus', 'libnagios-plugin-perl'], fatal=True)
    else:
        fetch.apt_install(['python-dbus', 'libmonitoring-plugin-perl'])
    hostname = nrpe.get_nagios_hostname()
    current_unit = nrpe.get_nagios_unit_name()
    nrpe_setup = nrpe.NRPE(hostname=hostname)
    helper.create_nrpe_checks(nrpe_setup, hostname, current_unit)
    remove_state('nrpe.render')


# use @hook here because @when('config.changed') misses changes to templates or files on charm upgrade
@hook('config-changed')
def do_config():
    set_state('files.render')
    set_state('nrpe.render')


@when('files.render')
def deploy_files():
    helper.deploy_scripts()
    helper.deploy_sudoers()
    remove_state('files.render')
    hookenv.status_set('active', 'ready')
