#!/usr/bin/python3
from unittest import mock

import pytest


class TestLib():
    def test_pytest(self):
        assert True

    def test_infranode(self, infranode):
        """See if the helper fixture works to load charm configs """
        assert isinstance(infranode.charm_config, dict)

    # Include tests for functions in lib_infra_node

    @pytest.mark.parametrize(
        "distrib, call",
        [
            ("focal", False),
            ("jammy", False),
            ("eoan", False),
            ("bionic", True),
            ("xenial", True),
        ],
    )
    @mock.patch("lib_infra_node.get_distrib_codename")
    def test_add_nrpe_pacemaker_corosync_ring_check(
        self,
        mock_distrib_codename,
        infranode,
        mock_nrpe_setup,
        mock_environ,
        mock_os_makedirs,
        mock_shutil_copy2,
        distrib,
        call,
    ):
        """Remove corosync check if distrib codename > eoan."""
        mock_distrib_codename.return_value = distrib
        infranode.create_nrpe_checks(
            mock_nrpe_setup, 'mock_hostname', 'mock_unit/0'
        )
        infranode.add_nrpe_pacemaker(mock_nrpe_setup, 'unittest')
        if call:
            mock_nrpe_setup.add_check.assert_any_call(
                'corosync_rings',
                'Check Corosync rings unittest',
                'check_corosync_rings',
            )
        else:
            mock_nrpe_setup.remove_check.assert_any_call(
                'corosync_rings',
                'Check Corosync rings unittest',
                'check_corosync_rings',
            )

    def test_add_nrpe_pacemaker(self, infranode, mock_nrpe_setup, mock_environ, mock_os_makedirs, mock_shutil_copy2):
        infranode.add_nrpe_pacemaker(mock_nrpe_setup, 'unittest')
        mock_nrpe_setup.add_check.assert_called()
        mock_nrpe_setup.add_check.assert_any_call(
            'crm_attr_pgsql-status',
            'Check crm attribute pgsql-status unittest',
            'check_crm_attribute -a pgsql-status -e PRI,HS:sync,HS:async'
        )
        mock_nrpe_setup.write.assert_called()

    def test_create_nrpe_checks_apt_maas(self, mock_nrpe_setup, infranode, mock_rsync):
        with mock.patch('os.path.isfile', return_value=False):
            infranode.create_nrpe_checks(mock_nrpe_setup, 'mock_hostname', 'mock_unit/0')
        mock_nrpe_setup.add_check.assert_any_call(
            shortname='maas-rackd',
            description='process check {mock_unit/0}',
            check_cmd='check_systemd.py maas-rackd'
        )
        mock_nrpe_setup.add_check.assert_any_call(
            shortname='maas-proxy',
            description='process check {mock_unit/0}',
            check_cmd='check_systemd.py maas-proxy'
        )
        mock_nrpe_setup.add_check.assert_any_call(
            shortname='bind9',
            description='process check {mock_unit/0}',
            check_cmd='check_systemd.py bind9'
        )
        mock_nrpe_setup.write.assert_called()

    def test_create_nrpe_checks_snap_maas(self, mock_nrpe_setup, infranode, mock_rsync):
        with mock.patch('os.path.isfile', return_value=True):
            infranode.create_nrpe_checks(mock_nrpe_setup, 'mock_hostname', 'mock_unit/0')
        mock_nrpe_setup.add_check.assert_called_with(
            shortname='snap.maas.supervisor',
            description='process check {mock_unit/0}',
            check_cmd='check_systemd.py snap.maas.supervisor'
        )
        mock_nrpe_setup.write.assert_called()
